@@ -78,7 +78,7 @@ def get_logger(
 LOGGER = get_logger('utilities')
 
 
-def create_symlink(source_filename: PathLike, symlink_filename: PathLike):
+def create_symlink(source_filename: PathLike, symlink_filename: PathLike, relative: bool = False):
     if not isinstance(source_filename, Path):
         source_filename = Path(source_filename)
     if not isinstance(symlink_filename, Path):
@@ -88,12 +88,24 @@ def create_symlink(source_filename: PathLike, symlink_filename: PathLike):
         LOGGER.debug(f'removing symlink {symlink_filename}')
         os.remove(symlink_filename)
 
+    symlink_filename = symlink_filename.parent.resolve() / symlink_filename.name
+    source_filename = source_filename.resolve()
+
+    starting_directory = None
+    if relative:
+        starting_directory = Path(os.getcwd())
+        os.chdir(source_filename.parent)
+        source_filename = source_filename.relative_to(symlink_filename.parent)
+
     try:
         symlink_filename.symlink_to(source_filename)
     except Exception as error:
         LOGGER.warning(f'could not create symbolic link: {error}')
         shutil.copyfile(source_filename, symlink_filename)
 
+    if starting_directory is not None:
+        os.chdir(starting_directory)
+
 
 def parse_datetime(value: Union[int, float, str, datetime]):
     if not isinstance(value, datetime):
